1.15.0 “Daredonkey” — Rucio 1.2 documentation

# 1.15.0 “Daredonkey”

## General

### Update Instructions

This feature release requires a database schema update. Please consult the documentation about updating your database schema.

### Features

- Clients: extend download/upload for cloud checksums #140
- Core & Internals: Pluggable LFN2PFN algorithms #570

### Enhancements

- Clients: Misleading warning in srm scheme #575
- Core & Internals: better handling NoSectionError in db/sqla/session #641
- Core & Internals: documentation: database versioning #749
- Documentation: Update concepts & terminology section of the documentation #566
- Documentation: Add auto-generated CLIs documentation for the daemons #718
- Documentation: documentation for Installing dev environment #725
- Documentation: Broken readthedocs compilation with No such file or directory #731
- Documentation: Format architecture section and add figure to the documentation #763
- Documentation: Fix broken rucio-admin CLI doc generation #769
- RSE Manager: Shuffle equal-weight protocols #697
- Release management: Possibility to make a pip install directly from git url #532
- Release management: core dependencies update #757
- Testing: provide docker compose file for demo containers #549
- Testing: pylint in travis wrongly test all files containing ‘py’ in the name #688
- Transfers: transfers: force S3 alternative authentication method #646
- Transfers: Improvements in finisher #678
- Transfers: Omit any mention of space tokens to FTS if not set #684

### Bugs

- Core & Internals: custom rucio exceptions passing args and kwargs wrong to super #679
- Core & Internals: DuplicateRule error creates index out of bound stacktrace #906

## Clients

### Features

- Clients: Import extra modules only if they are available #336
- Clients: Create download and upload capability in python clients #523

### Bugs

- Clients: Declare all replicas of a file lost #42

## WebUI

### Enhancements

- Authentication: webui cannot handle DNs with missing leading / #742